from with_test import test, test_case, get_test_self, inject, inject_customized_must_method

__author__ = 'Colin Ji'
__versioninfo__ = (1, 2, 0)
__version__ = '.'.join(map(str, __versioninfo__))

__all__ = ['test', 'test_case', 'get_test_self', 'inject', 'inject_customized_must_method']
